==> dbacl-1.8.1.tar.gz: dbacl-1.8.1/src/risk-parser.h <==
/* A Bison parser, made by GNU Bison 1.875a.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     tCATEGORIES = 258,
     tPRIOR = 259,
     tLOSS = 260,
     tEXP = 261,
     tLOG = 262,
     tNUMBER = 263,
     tMATCH = 264,
     tCOMPLEXITY = 265,
     tNAME = 266,
     tREGEX = 267,
     tVEC = 268
   };
#endif
#define tCATEGORIES 258
#define tPRIOR 259
#define tLOSS 260
#define tEXP 261
#define tLOG 262
#define tNUMBER 263
#define tMATCH 264
#define tCOMPLEXITY 265
#define tNAME 266
#define tREGEX 267
#define tVEC 268




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 51 "risk-parser.y"
typedef union YYSTYPE {
  real_value_t numval;
  char *strval;
} YYSTYPE;
/* Line 1240 of yacc.c.  */
#line 68 "y.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

==> dbacl_1.12.orig.tar.gz: dbacl-1.12/src/risk-parser.h <==
/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     tCATEGORIES = 258,
     tPRIOR = 259,
     tLOSS = 260,
     tEXP = 261,
     tLOG = 262,
     tNUMBER = 263,
     tMATCH = 264,
     tCOMPLEXITY = 265,
     tNAME = 266,
     tREGEX = 267,
     tVEC = 268
   };
#endif
/* Tokens.  */
#define tCATEGORIES 258
#define tPRIOR 259
#define tLOSS 260
#define tEXP 261
#define tLOG 262
#define tNUMBER 263
#define tMATCH 264
#define tCOMPLEXITY 265
#define tNAME 266
#define tREGEX 267
#define tVEC 268




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 51 "risk-parser.y"
typedef union YYSTYPE {
  real_value_t numval;
  char *strval;
} YYSTYPE;
/* Line 1447 of yacc.c.  */
#line 69 "risk-parser.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;
